@@ -111,7 +111,7 @@ class TestUtilities(object):
         if not columnType:
             raise ValueError("column type cannot be None...")
 
-        factTypes = set(ShortType(), IntegerType(), LongType(), FloatType(), DoubleType(), DecimalType())
+        factTypes = [ShortType(), IntegerType(), LongType(), FloatType(), DoubleType(), DecimalType()]
 
         return (columnType in factTypes)
 
